require 'active_model_serializers'
require 'closure_tree'
require 'paperclip'
require 'el_finder2/engine'

module ElFinder2
  API_VERSION = '2.1'
  VOLUME_ID = 'v0'
  IMAGE_MIME_REGEX = /\A(image|(x-)?application)\/(bmp|gif|p?jpeg|jpg|(x-)?png)\Z/

  def self.configuration
    @configuration ||= Configuration.new
  end

  def self.configure(&block)
    configuration.tap(&block)
  end

  class Configuration
    attr_accessor :document_validations
    attr_accessor :image_validations
    attr_accessor :document_options
    attr_accessor :image_options
    attr_accessor :default_options

    def initialize
      @document_validations = {
        presence: true,
        file_type_ignorance: {}
      }
      @image_validations = {
        presence: true,
        content_type: { content_type: ElFinder2::IMAGE_MIME_REGEX }
      }

      @default_options = {}
      @image_options = {
        styles: { thumb: '100x100>' }
      }
      @document_options = {}
    end

    def image_attachment
      @default_options.merge(@image_options)
    end

    def document_attachment
      @default_options.merge(@document_options)
    end
  end
end
